==> hazelcast-all-3.12.12-sources.jar: com/hazelcast/spi/impl/merge/CardinalityEstimatorMergingEntry.java <==
/*
 * Copyright (c) 2008-2020, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.spi.impl.merge;

import com.hazelcast.cardinality.impl.hyperloglog.HyperLogLog;
import com.hazelcast.spi.merge.SplitBrainMergeTypes.CardinalityEstimatorMergeTypes;
import com.hazelcast.spi.serialization.SerializationService;

/**
 * Implementation of {@link CardinalityEstimatorMergeTypes}.
 *
 * @since 3.10
 */
@SuppressWarnings("WeakerAccess")
public class CardinalityEstimatorMergingEntry
        extends AbstractMergingEntryImpl<String, HyperLogLog, CardinalityEstimatorMergingEntry>
        implements CardinalityEstimatorMergeTypes {

    public CardinalityEstimatorMergingEntry() {
    }

    public CardinalityEstimatorMergingEntry(SerializationService serializationService) {
        super(serializationService);
    }

    @Override
    public int getId() {
        return SplitBrainDataSerializerHook.CARDINALITY_ESTIMATOR_MERGING_ENTRY;
    }
}

==> hazelcast-all-4.1.7-sources.jar: com/hazelcast/spi/impl/merge/CardinalityEstimatorMergingEntry.java <==
/*
 * Copyright (c) 2008-2020, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.spi.impl.merge;

import com.hazelcast.cardinality.impl.hyperloglog.HyperLogLog;
import com.hazelcast.spi.merge.SplitBrainMergeTypes.CardinalityEstimatorMergeTypes;
import com.hazelcast.internal.serialization.SerializationService;

/**
 * Implementation of {@link CardinalityEstimatorMergeTypes}.
 *
 * @since 3.10
 */
@SuppressWarnings("WeakerAccess")
public class CardinalityEstimatorMergingEntry
        extends AbstractMergingEntryImpl<String, HyperLogLog, CardinalityEstimatorMergingEntry>
        implements CardinalityEstimatorMergeTypes {

    public CardinalityEstimatorMergingEntry() {
    }

    public CardinalityEstimatorMergingEntry(SerializationService serializationService) {
        super(serializationService);
    }

    @Override
    public int getClassId() {
        return SplitBrainDataSerializerHook.CARDINALITY_ESTIMATOR_MERGING_ENTRY;
    }
}
